@@ -1,9 +1,9 @@
-import downloader
+from . import downloader
 
 from dotenv import load_dotenv
 
 from flask import Flask, request
-from werkzeug.exceptions import BadRequest
+from werkzeug.exceptions import Forbidden
 
 from super_eureka import logging
 
@@ -21,7 +21,7 @@ def main():
         if download_link:
             downloader.download_and_process(download_link)
             return 'The download process was initiated.'
-    raise BadRequest
+    raise Forbidden
 
 
 # added because of wsgi
